@@ -1018,6 +1018,38 @@ class TestFileHandling(TestCaseWithTempDir):
         output = self.output.getvalue()
         self.assertIn("(changed)", output)
 
+    def testPrintOutput(self):
+        d = {
+            'test.cog': """\
+                // This is my C++ file.
+                //[[[cog
+                fnames = ['DoSomething', 'DoAnotherThing', 'DoLastThing']
+                for fn in fnames:
+                    print("void %s();" % fn)
+                //]]]
+                //[[[end]]]
+                """,
+
+            'test.out': """\
+                // This is my C++ file.
+                //[[[cog
+                fnames = ['DoSomething', 'DoAnotherThing', 'DoLastThing']
+                for fn in fnames:
+                    print("void %s();" % fn)
+                //]]]
+                void DoSomething();
+                void DoAnotherThing();
+                void DoLastThing();
+                //[[[end]]]
+                """,
+            }
+
+        makeFiles(d)
+        self.cog.callableMain(['argv0', '-rP', 'test.cog'])
+        self.assertFilesSame('test.cog', 'test.out')
+        output = self.output.getvalue()
+        self.assertIn("(changed)", output)
+
     def testWildcards(self):
         d = {
             'test.cog': """\
@@ -1998,7 +2030,7 @@ class CogTestsInFiles(TestCaseWithTempDir):
         self.assertFilesSame('test.cog', 'test.out')
 
     def testThreads(self):
-        # Test that the implictly imported cog module is actually different for
+        # Test that the implicitly imported cog module is actually different for
         # different threads.
         numthreads = 20
 
@@ -2021,7 +2053,7 @@ class CogTestsInFiles(TestCaseWithTempDir):
                     ['cog.py', '-r', '-D', 'FIRST={}'.format(num+1), 'f{}.cog'.format(num)]
                     )
                 assert ret == 0
-            except Exception as exc:
+            except Exception as exc:    # pragma: no cover (only happens on test failure)
                 results.append(exc)
             else:
                 results.append(None)
